/// <reference types="cypress" />

describe('Should allow valid user and block the rest', () => {

    beforeEach(function() {
        // Changed theses should as required conditions to perform other tests 
        cy.visit('http://localhost:3000')
        // title
        cy.title().should('eq', 'QA @ Trusk')
        // elements
        cy.get('h1').should('be.visible')
        cy.get('p').should('be.visible')
        cy.get('label').should('be.visible')
        cy.get('input').should('be.visible')
        cy.get('button').should('be.visible')
    
    });

    it('Prevent submiting empty credentials', function() {
        // submit empty
        cy.get('input').first().clear()
        cy.get('input').last().clear()
        cy.get('button').click()
        cy.contains('Renseignes une adresse e-mail!').should('be.visible')
        cy.contains('Renseignes un mot de passe!').should('be.visible')
    });


    it('Prevent submiting malformed email', function() {
        // submit invalid email
        cy.get('input').first().clear().type('adrian-trusk')
        cy.get('button').click()
        cy.contains('Renseignes une adresse e-mail valide!').should('be.visible')
    });

    it('Prevent submiting an unexisting user', function() {
        // submit wrong email
        cy.get('input').first().clear().type('adrian.pothuaud@trusk.com')
        cy.get('button').click()
        cy.contains('Renseignes la bonne adresse e-mail!').should('be.visible')
        cy.contains('Renseignes le bon mot de passe').should('be.visible')
    });

    it('Prevent submiting invalid password of an existing user', function() {
        // submit bad password
        cy.get('input').first().clear().type('adrian@trusk.com')
        cy.get('input').last().clear().type('adrian')
        cy.get('button').click()
    });

    it('Allow connect a user in the system with right credentials', function() {
        // submit valid credentials
        cy.get('input').first().clear().type('adrian@trusk.com')
        cy.get('input').last().clear().type('adrian@trusk.com')
        cy.get('button').click()
        cy.contains('Salut testeur !').should('be.visible')

    });

    it.skip('Allow to disconnect a connected user', function() {
        // get back
        cy.contains('Retour').click()
        cy.title().should('eq', 'QA @ Trusk')
        cy.get('h1').should('be.visible')
        cy.get('p').should('be.visible')
        cy.get('label').should('be.visible')
        cy.get('input').should('be.visible')
        cy.get('button').should('be.visible')
    });

});